# PyLibreHardwareMonitorLib

This is a repository of LibreHardwareMonitorLib.dll files from various releases of LibreHardwareMonitorLib for use in the PyLibreHardwareMonitor project.

这是 LibreHardwareMonitorLib 的各个 releases 版本的 LibreHardwareMonitorLib.dll 文件库, 供 PyLibreHardwareMonitor 项目使用.
